@@ -15,13 +15,14 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with this program; if not, write to the Free Software
-# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+# Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301 USA
 #
 # On Debian GNU/Linux systems, a copy of the GNU General Public License may be
 # found in the file /usr/share/common-licenses/GPL.
 
 use strict;
-use Net::LDAP;
+my $LDAPENABLED = eval "use Net::LDAP; 1" ? '1' : '0';
+
 use Getopt::Std;
 use NetAddr::IP;
 
@@ -1437,6 +1438,7 @@ sub readCommandLine {
 	}
 
 	if ($readldap || $writeldap) {
+		if ($LDAPENABLED == 0) { die "To use LDAP fatures be sure to install Net::LDAP from debain package libnet-ldap-perl" } ;
 		$ldap = Net::LDAP->new($ldapserver) or die "$@";
 		if ($ldapbinddn && ($ldappassword eq "")) {
 			$mesg=$ldap->bind(	$ldapbinddn);
